@@ -22,8 +22,10 @@ define([
     '../com/component/Component',
     '../com/component/FileNavigation',
     './Block',
-    './BlockMenu'
-], function(boardFrameHtml, boardFrameCss, com_Config, com_String, com_util, com_interface, Component, FileNavigation, Block, BlockMenu) {
+    './BlockMenu',
+    './CodeView'
+], function(boardFrameHtml, boardFrameCss, com_Config, com_String, com_util, com_interface, 
+            Component, FileNavigation, Block, BlockMenu, CodeView) {
 	'use strict';
     //========================================================================
     // Define Variable
@@ -88,7 +90,7 @@ define([
                 let menu = $(this).data('menu');
                 switch (menu) {
                     case 'new':
-                        that.createNewNote();
+                        that.createNewNoteWithChecking();
                         break;
                     case 'open':
                         that.openNote();
@@ -102,14 +104,14 @@ define([
                     case 'run-all':
                         that.runAll();
                         break;
-                    case 'view-depth':
-                        that.viewDepthInfo();
+                    case 'code-view':
+                        that.viewCode();
+                        break;
+                    case 'code-export':
+                        that.exportCode();
                         break;
                     case 'clear':
-                        that.clearBoard();
-                        break;
-                    case 'close':
-                        that.closeBoard();
+                        that.clearBoardWithChecking();
                         break;
                 }
             });
@@ -395,6 +397,7 @@ define([
             // show note area
             $(this.wrapSelector()).show();
             $('#vp_toggleBoard').removeClass('vp-hide');
+            $('#vp_toggleBoard').attr('title', 'Hide VP Note');
             // set width 
             let boardWidth = com_Config.BOARD_MIN_WIDTH;
             $(this.wrapSelector()).width(boardWidth);
@@ -408,6 +411,7 @@ define([
             if (!$('#vp_toggleBoard').hasClass('vp-hide')) {
                 $('#vp_toggleBoard').addClass('vp-hide');
             }
+            $('#vp_toggleBoard').attr('title', 'Show VP Note');
             // set width
             let boardWidth = 0;
             $(this.wrapSelector()).width(boardWidth);
@@ -425,9 +429,51 @@ define([
         //========================================================================
         // Note control
         //========================================================================
-        createNewNote() {
-            // TODO: alert before closing
+        /**
+         * Check if note has changes to save
+         */
+        checkNote() {
+            if (this.blockList.length > 0) {
+                return true;
+            }
+            return false;
+        }
+        createNewNoteWithChecking() {
+            // alert before closing
+            let that = this;
+            if (this.checkNote()) {
+                // render update modal
+                com_util.renderModal({
+                    title: 'Unsaved changes', 
+                    message: 'Do you want to save?',
+                    buttons: ['Cancel', 'No', 'Save'],
+                    defaultButtonIdx: 0,
+                    buttonClass: ['cancel', '', 'activated'],
+                    finish: function(clickedBtnIdx) {
+                        switch (clickedBtnIdx) {
+                            case 0:
+                                // cancel - do nothing
+                                return;
+                            case 1:
+                                // don't save
+                                that.createNewNote();
+                                break;
+                            case 2:
+                                // save
+                                that.saveAsNote(function() {
+                                    that.createNewNote();
+                                });
+                                break;
+                        }
+                    }
+                });
 
+                return;
+            }
+
+            this.createNewNote();
+        }
+        createNewNote() {
             // clear board before create new note
             this.clearBoard();
 
@@ -462,19 +508,23 @@ define([
                 
                         file.text().then(function(data) {
                             // var parsedData = decodeURIComponent(data);
-                            var jsonList = JSON.parse(data);
-                            // load blocks
-                            that.jsonToBlock(jsonList);
-
-                            var indexVp = vpFileName.indexOf('.vp');
-                            var saveFileName = vpFileName.slice(0,indexVp);
-            
-                            // show title of board and path
-                            $('#vp_boardTitle').val(saveFileName);
-                            that.tmpState.boardTitle = saveFileName;
-                            that.tmpState.boardPath = vpFilePath;
-
-                            com_util.renderSuccessMessage('Successfully opened file. (' + vpFileName + ')');
+                            try {
+                                var jsonList = JSON.parse(data);
+                                // load blocks
+                                that.jsonToBlock(jsonList);
+    
+                                var indexVp = vpFileName.indexOf('.vp');
+                                var saveFileName = vpFileName.slice(0,indexVp);
+                
+                                // show title of board and path
+                                $('#vp_boardTitle').val(saveFileName);
+                                that.tmpState.boardTitle = saveFileName;
+                                that.tmpState.boardPath = vpFilePath;
+    
+                                com_util.renderSuccessMessage('Successfully opened file. (' + vpFileName + ')');
+                            } catch (ex) {
+                                com_util.renderAlertModal('Not applicable file contents with vp format! (JSON)');
+                            }
                         });
                     });
                 }
@@ -498,7 +548,7 @@ define([
 
             this.saveAsNote();
         }
-        saveAsNote() {
+        saveAsNote(callback) {
             let that = this;
             // save file navigation
             let fileNavi = new FileNavigation({ 
@@ -521,25 +571,48 @@ define([
                     that.tmpState.boardTitle = boardTitle;
                     that.tmpState.boardPath = boardPath;
                     $('#vp_boardTitle').val(boardTitle);
+
+                    if (callback != undefined && typeof callback === 'function') {
+                        callback();
+                    }
                 }
             });
             fileNavi.open();
         }
-        runBlock(block, execute=true) {
+        runBlock(block, execute=true, addcell=true) {
             if (block.id == 'apps_markdown') {
                 // if markdown, run single
-                block.popup.run();
-                return;
+                return block.popup.run(execute, addcell);
             }
+            let rootBlockDepth = block.depth;
             let groupedBlocks = block.getGroupedBlocks();
             let code = new com_String();
             let indentCount = this.state.indentCount;
             groupedBlocks.forEach((groupBlock, idx) => {
                 let prevNewLine = idx > 0?'\n':'';
-                let indent = ' '.repeat(groupBlock.depth * indentCount);
-                code.appendFormat('{0}{1}{2}', prevNewLine, indent, groupBlock.popup.generateCode());
+                let indent = ' '.repeat((groupBlock.depth - rootBlockDepth) * indentCount);
+                let thisBlockCode = groupBlock.popup.generateCode();
+                if (Array.isArray(thisBlockCode)) {
+                    for (let i = 0; i < thisBlockCode.length; i++) {
+                        thisBlockCode[i] = thisBlockCode[i].replaceAll('\n', '\n' + indent);
+                    }
+                    if (addcell) {
+                        // insert single cell using prev code
+                        com_interface.insertCell('code', code.toString(), execute, block.blockNumber);
+                        code = new com_String();
+                        // insert cells using this block code list
+                        com_interface.insertCells('code', thisBlockCode, execute, block.blockNumber);
+                    }
+                } else {
+                    // set indent to every line of thisblockcode
+                    thisBlockCode = thisBlockCode.replaceAll('\n', '\n' + indent);
+                    code.appendFormat('{0}{1}{2}', prevNewLine, indent, thisBlockCode);
+                }
             });
-            com_interface.insertCell('code', code.toString(), execute, block.blockNumber);
+            if (addcell) {
+                com_interface.insertCell('code', code.toString(), execute, block.blockNumber);
+            }
+            return code.toString();
         }
         runAll() {
             let that = this;
@@ -549,17 +622,106 @@ define([
                 }
             })
         }
-        viewDepthInfo() {
-            this.state.viewDepthNumber = !this.state.viewDepthNumber;
+        getOverallCode() {
+            let overallCode = new com_String();
+            let that = this;
+            this.blockList.forEach((block) => {
+                if (block.isGroup) {
+                    if (overallCode.toString() != '') {
+                        overallCode.appendLine();
+                        overallCode.appendLine();
+                    }
+                    let groupCode = that.runBlock(block, false, false);
+                    if (block.id == 'apps_markdown') {
+                        // if markdown, add #
+                        groupCode = '#' + groupCode.replaceAll('\n', '\n# ');
+                    }
+                    overallCode.appendFormatLine('# VisualPython [{0}]{1}', block.blockNumber,
+                        block.id == 'apps_markdown'? ' - Markdown':'');
+                    overallCode.append(groupCode);
+                }
+            });
+            return overallCode.toString();
+        }
+        viewCode() {
+            let overallCode = this.getOverallCode();
+            let codeview = new CodeView({ 
+                codeview: overallCode,
+                config: {
+                    id: 'boardCodeview',
+                    name: 'Overall Codeview',
+                    path: ''
+                }
+            });
+            codeview.open();
+        }
+        exportCode() {
+            let that = this;
+            // save .py file
+            let fileNavi = new FileNavigation({
+                type: 'save',
+                fileName: this.tmpState.boardTitle,
+                extensions: ['py'],
+                finish: function(filesPath, status, error) {
+                    let fileName = filesPath[0].file;
+                    let filePath = filesPath[0].path;
 
-            if (this.state.viewDepthNumber) {
-                $(this.wrapSelector('.vp-board-header-button-inner li[data-menu="view-depth"]')).text('Hide Depth Number');
-            } else {
-                $(this.wrapSelector('.vp-board-header-button-inner li[data-menu="view-depth"]')).text('View Depth Number');
+                    // save py file
+                    let overallCode = that.getOverallCode();
+                    vpKernel.saveFile(fileName, filePath, overallCode);
+                }
+            });
+            fileNavi.open();
+        }
+        /**
+         * Deprecated on v2.0.2.
+         */
+        // viewDepthInfo() {
+        //     this.state.viewDepthNumber = !this.state.viewDepthNumber;
+
+        //     if (this.state.viewDepthNumber) {
+        //         $(this.wrapSelector('.vp-board-header-button-inner li[data-menu="view-depth"]')).text('Hide Depth Number');
+        //     } else {
+        //         $(this.wrapSelector('.vp-board-header-button-inner li[data-menu="view-depth"]')).text('View Depth Number');
+        //     }
+
+        //     // reloadBlockList
+        //     this.reloadBlockList();
+        // }
+        clearBoardWithChecking() {
+            // alert before closing
+            let that = this;
+            if (this.checkNote()) {
+                // render update modal
+                com_util.renderModal({
+                    title: 'Unsaved changes', 
+                    message: 'Do you want to save?',
+                    buttons: ['Cancel', "No", 'Save'],
+                    defaultButtonIdx: 0,
+                    buttonClass: ['cancel', '', 'activated'],
+                    finish: function(clickedBtnIdx) {
+                        switch (clickedBtnIdx) {
+                            case 0:
+                                // cancel - do nothing
+                                return;
+                            case 1:
+                                // don't save
+                                that.clearBoard();
+                                break;
+                            case 2:
+                                // save
+                                that.saveAsNote(function() {
+                                    that.clearBoard();
+                                });
+                                break;
+                        }
+                    }
+                });
+
+                return;
             }
 
-            // reloadBlockList
-            this.reloadBlockList();
+            this.clearBoard();
         }
         clearBoard() {
             // TODO: alert before clearing
@@ -573,9 +735,12 @@ define([
             // render block list  
             this.reloadBlockList();
         }
-        closeBoard() {
-            this.createNewNote();
-        }
+        /**
+         * Deprecated on v2.0.2.
+         */
+        // closeBoard() {
+        //     this.createNewNote();
+        // }
         //========================================================================
         // Block control
         //========================================================================
@@ -768,6 +933,10 @@ define([
                 if (elseBlock.length > 0) {
                     this.removeBlock(elseBlock[0]);
                 }
+                // focus it
+                setTimeout(function() {
+                    block.focusItem();
+                }, 100);
             }
         }
 
@@ -800,6 +969,10 @@ define([
                 if (finallyBlock) {
                     this.removeBlock(finallyBlock);
                 }
+                // focus it
+                setTimeout(function() {
+                    block.focusItem();
+                }, 100);
             }
         }
 
